This is the core package for XenoSite.

This package primarily serves as a namespace package for the xenosite family of packages, while also including an extensible command line interface. All useful functionality requires installing one of the XenoSite subpackages.